@@ -171,14 +171,9 @@ function _grow_star(v, w, e_idx, firstNeighbor, color, S)
     @inbounds if p != v
         firstNeighbor[color[w]] = _Edge(e_idx, v, w)
     else
-        _root_union!(S, e_idx, e.index)
-    end
-    return
-end
-
-function _merge_trees(S::_IntDisjointSet, eg::Int, eg1::Int)
-    if _find_root!(S, eg) != _find_root!(S, eg1)
-        _root_union!(S, eg, eg1)
+        root1 = _find_root!(S, e_idx)
+        root2 = _find_root!(S, e.index)
+        _root_union!(S, root1, root2)
     end
     return
 end
@@ -280,7 +275,7 @@ function acyclic_coloring(g::UndirectedGraph)
                     continue
                 end
                 if color[x] == color[v]
-                    _merge_trees(S, e_idx, e2_idx)
+                    _union!(S, e_idx, e2_idx)
                 end
             end
         end
